django\_sorcery.management.commands.sorcery\_history module
===========================================================

.. automodule:: django_sorcery.management.commands.sorcery_history
   :members:
   :undoc-members:
   :show-inheritance:
